From bf4e1cd53ba438c91071b6a0eab7013ca7f93d2e Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?J=C3=B6rg=20Buchwald?= <joerg.buchwald@ufz.de>
Date: Tue, 1 Jun 2021 15:17:27 +0200
Subject: [PATCH] rename HeatConduction -> ThermalConductivity

---
 .../c_SaturationDependentHeatConduction.md         |  1 -
 .../SaturationDependentHeatConduction/t_dry.md     |  1 -
 .../SaturationDependentHeatConduction/t_wet.md     |  1 -
 .../c_SaturationDependentThermalConductivity.md    |  1 +
 .../t_dry.md                                       |  1 +
 .../t_wet.md                                       |  1 +
 MaterialLib/MPL/CreateProperty.cpp                 |  4 ++--
 MaterialLib/MPL/Properties/CreateProperties.h      |  2 +-
 ...eateSaturationDependentThermalConductivity.cpp} | 14 +++++++-------
 ...CreateSaturationDependentThermalConductivity.h} |  6 +++---
 MaterialLib/MPL/Properties/Properties.h            |  2 +-
 ... => SaturationDependentThermalConductivity.cpp} | 14 +++++++-------
 ....h => SaturationDependentThermalConductivity.h} |  8 ++++----
 ...TestSaturationDependentThermalConductivity.cpp} |  8 ++++----
 14 files changed, 32 insertions(+), 32 deletions(-)
 delete mode 100644 Documentation/ProjectFile/properties/property/SaturationDependentHeatConduction/c_SaturationDependentHeatConduction.md
 delete mode 100644 Documentation/ProjectFile/properties/property/SaturationDependentHeatConduction/t_dry.md
 delete mode 100644 Documentation/ProjectFile/properties/property/SaturationDependentHeatConduction/t_wet.md
 create mode 100644 Documentation/ProjectFile/properties/property/SaturationDependentThermalConductivity/c_SaturationDependentThermalConductivity.md
 create mode 100644 Documentation/ProjectFile/properties/property/SaturationDependentThermalConductivity/t_dry.md
 create mode 100644 Documentation/ProjectFile/properties/property/SaturationDependentThermalConductivity/t_wet.md
 rename MaterialLib/MPL/Properties/{CreateSaturationDependentHeatConduction.cpp => CreateSaturationDependentThermalConductivity.cpp} (72%)
 rename MaterialLib/MPL/Properties/{CreateSaturationDependentHeatConduction.h => CreateSaturationDependentThermalConductivity.h} (71%)
 rename MaterialLib/MPL/Properties/{SaturationDependentHeatConduction.cpp => SaturationDependentThermalConductivity.cpp} (73%)
 rename MaterialLib/MPL/Properties/{SaturationDependentHeatConduction.h => SaturationDependentThermalConductivity.h} (81%)
 rename Tests/MaterialLib/{TestSaturationDependentHeatConduction.cpp => TestSaturationDependentThermalConductivity.cpp} (82%)

diff --git a/Documentation/ProjectFile/properties/property/SaturationDependentHeatConduction/c_SaturationDependentHeatConduction.md b/Documentation/ProjectFile/properties/property/SaturationDependentHeatConduction/c_SaturationDependentHeatConduction.md
deleted file mode 100644
index c928cd424fd..00000000000
--- a/Documentation/ProjectFile/properties/property/SaturationDependentHeatConduction/c_SaturationDependentHeatConduction.md
+++ /dev/null
@@ -1 +0,0 @@
-\copydoc MaterialPropertyLib::SaturationDependentHeatConduction
diff --git a/Documentation/ProjectFile/properties/property/SaturationDependentHeatConduction/t_dry.md b/Documentation/ProjectFile/properties/property/SaturationDependentHeatConduction/t_dry.md
deleted file mode 100644
index b59f76999f9..00000000000
--- a/Documentation/ProjectFile/properties/property/SaturationDependentHeatConduction/t_dry.md
+++ /dev/null
@@ -1 +0,0 @@
-\copydoc MaterialPropertyLib::SaturationDependentHeatConduction::K_dry_
diff --git a/Documentation/ProjectFile/properties/property/SaturationDependentHeatConduction/t_wet.md b/Documentation/ProjectFile/properties/property/SaturationDependentHeatConduction/t_wet.md
deleted file mode 100644
index c5faa321fcf..00000000000
--- a/Documentation/ProjectFile/properties/property/SaturationDependentHeatConduction/t_wet.md
+++ /dev/null
@@ -1 +0,0 @@
-\copydoc MaterialPropertyLib::SaturationDependentHeatConduction::K_wet_
diff --git a/Documentation/ProjectFile/properties/property/SaturationDependentThermalConductivity/c_SaturationDependentThermalConductivity.md b/Documentation/ProjectFile/properties/property/SaturationDependentThermalConductivity/c_SaturationDependentThermalConductivity.md
new file mode 100644
index 00000000000..e62ca92b209
--- /dev/null
+++ b/Documentation/ProjectFile/properties/property/SaturationDependentThermalConductivity/c_SaturationDependentThermalConductivity.md
@@ -0,0 +1 @@
+\copydoc MaterialPropertyLib::SaturationDependentThermalConductivity
diff --git a/Documentation/ProjectFile/properties/property/SaturationDependentThermalConductivity/t_dry.md b/Documentation/ProjectFile/properties/property/SaturationDependentThermalConductivity/t_dry.md
new file mode 100644
index 00000000000..60ba6f6ced7
--- /dev/null
+++ b/Documentation/ProjectFile/properties/property/SaturationDependentThermalConductivity/t_dry.md
@@ -0,0 +1 @@
+\copydoc MaterialPropertyLib::SaturationDependentThermalConductivity::K_dry_
diff --git a/Documentation/ProjectFile/properties/property/SaturationDependentThermalConductivity/t_wet.md b/Documentation/ProjectFile/properties/property/SaturationDependentThermalConductivity/t_wet.md
new file mode 100644
index 00000000000..f21b3559c2e
--- /dev/null
+++ b/Documentation/ProjectFile/properties/property/SaturationDependentThermalConductivity/t_wet.md
@@ -0,0 +1 @@
+\copydoc MaterialPropertyLib::SaturationDependentThermalConductivity::K_wet_
diff --git a/MaterialLib/MPL/CreateProperty.cpp b/MaterialLib/MPL/CreateProperty.cpp
index d3dba9812fd..80928ee14e3 100644
--- a/MaterialLib/MPL/CreateProperty.cpp
+++ b/MaterialLib/MPL/CreateProperty.cpp
@@ -210,9 +210,9 @@ std::unique_ptr<MaterialPropertyLib::Property> createProperty(
         return createRelPermUdellNonwettingPhase(config);
     }
 
-    if (boost::iequals(property_type, "SaturationDependentHeatConduction"))
+    if (boost::iequals(property_type, "SaturationDependentThermalConductivity"))
     {
-        return createSaturationDependentHeatConduction(config);
+        return createSaturationDependentThermalConductivity(config);
     }
 
     if (boost::iequals(property_type, "SaturationDependentSwelling"))
diff --git a/MaterialLib/MPL/Properties/CreateProperties.h b/MaterialLib/MPL/Properties/CreateProperties.h
index de51caa2889..18be387e04d 100644
--- a/MaterialLib/MPL/Properties/CreateProperties.h
+++ b/MaterialLib/MPL/Properties/CreateProperties.h
@@ -37,7 +37,7 @@
 #include "CreateOrthotropicEmbeddedFracturePermeability.h"
 #include "CreatePermeabilityOrthotropicPowerLaw.h"
 #include "CreatePorosityFromMassBalance.h"
-#include "CreateSaturationDependentHeatConduction.h"
+#include "CreateSaturationDependentThermalConductivity.h"
 #include "CreateSaturationDependentSwelling.h"
 #include "CreateStrainDependentPermeability.h"
 #include "CreateTransportPorosityFromMassBalance.h"
diff --git a/MaterialLib/MPL/Properties/CreateSaturationDependentHeatConduction.cpp b/MaterialLib/MPL/Properties/CreateSaturationDependentThermalConductivity.cpp
similarity index 72%
rename from MaterialLib/MPL/Properties/CreateSaturationDependentHeatConduction.cpp
rename to MaterialLib/MPL/Properties/CreateSaturationDependentThermalConductivity.cpp
index 3eb2f2d2c93..20242f16db0 100644
--- a/MaterialLib/MPL/Properties/CreateSaturationDependentHeatConduction.cpp
+++ b/MaterialLib/MPL/Properties/CreateSaturationDependentThermalConductivity.cpp
@@ -8,15 +8,15 @@
  */
 
 #include "BaseLib/ConfigTree.h"
-#include "SaturationDependentHeatConduction.h"
+#include "SaturationDependentThermalConductivity.h"
 
 namespace MaterialPropertyLib
 {
-std::unique_ptr<SaturationDependentHeatConduction>
-createSaturationDependentHeatConduction(BaseLib::ConfigTree const& config)
+std::unique_ptr<SaturationDependentThermalConductivity>
+createSaturationDependentThermalConductivity(BaseLib::ConfigTree const& config)
 {
     //! \ogs_file_param{properties__property__type}
-    config.checkConfigParameter("type", "SaturationDependentHeatConduction");
+    config.checkConfigParameter("type", "SaturationDependentThermalConductivity");
 
     // Second access for storage.
     //! \ogs_file_param{properties__property__name}
@@ -26,15 +26,15 @@ createSaturationDependentHeatConduction(BaseLib::ConfigTree const& config)
          property_name);
 
     auto const K_dry =
-        //! \ogs_file_param{properties__property__SaturationDependentHeatConduction__dry}
+        //! \ogs_file_param{properties__property__SaturationDependentThermalConductivity__dry}
         config.getConfigParameter<double>("dry");
 
     auto const K_wet =
-        //! \ogs_file_param{properties__property__SaturationDependentHeatConduction__wet}
+        //! \ogs_file_param{properties__property__SaturationDependentThermalConductivity__wet}
         config.getConfigParameter<double>("wet");
 
     return std::make_unique<
-        MaterialPropertyLib::SaturationDependentHeatConduction>(
+        MaterialPropertyLib::SaturationDependentThermalConductivity>(
         std::move(property_name), K_dry, K_wet);
 }
 }  // namespace MaterialPropertyLib
diff --git a/MaterialLib/MPL/Properties/CreateSaturationDependentHeatConduction.h b/MaterialLib/MPL/Properties/CreateSaturationDependentThermalConductivity.h
similarity index 71%
rename from MaterialLib/MPL/Properties/CreateSaturationDependentHeatConduction.h
rename to MaterialLib/MPL/Properties/CreateSaturationDependentThermalConductivity.h
index 8ddef20e052..f13b4ee7d0f 100644
--- a/MaterialLib/MPL/Properties/CreateSaturationDependentHeatConduction.h
+++ b/MaterialLib/MPL/Properties/CreateSaturationDependentThermalConductivity.h
@@ -18,11 +18,11 @@ class ConfigTree;
 
 namespace MaterialPropertyLib
 {
-class SaturationDependentHeatConduction;
+class SaturationDependentThermalConductivity;
 }
 
 namespace MaterialPropertyLib
 {
-std::unique_ptr<SaturationDependentHeatConduction>
-createSaturationDependentHeatConduction(BaseLib::ConfigTree const& config);
+std::unique_ptr<SaturationDependentThermalConductivity>
+createSaturationDependentThermalConductivity(BaseLib::ConfigTree const& config);
 }  // namespace MaterialPropertyLib
diff --git a/MaterialLib/MPL/Properties/Properties.h b/MaterialLib/MPL/Properties/Properties.h
index 290a0e43669..726d339d054 100644
--- a/MaterialLib/MPL/Properties/Properties.h
+++ b/MaterialLib/MPL/Properties/Properties.h
@@ -42,7 +42,7 @@
 #include "RelativePermeability/RelPermUdell.h"
 #include "RelativePermeability/RelPermUdellNonwettingPhase.h"
 #include "RelativePermeability/RelPermVanGenuchten.h"
-#include "SaturationDependentHeatConduction.h"
+#include "SaturationDependentThermalConductivity.h"
 #include "SaturationDependentSwelling.h"
 #include "ThermalConductivity/SoilThermalConductivitySomerton.h"
 #include "TransportPorosityFromMassBalance.h"
diff --git a/MaterialLib/MPL/Properties/SaturationDependentHeatConduction.cpp b/MaterialLib/MPL/Properties/SaturationDependentThermalConductivity.cpp
similarity index 73%
rename from MaterialLib/MPL/Properties/SaturationDependentHeatConduction.cpp
rename to MaterialLib/MPL/Properties/SaturationDependentThermalConductivity.cpp
index a08c07fd062..dc7f54cdfd7 100644
--- a/MaterialLib/MPL/Properties/SaturationDependentHeatConduction.cpp
+++ b/MaterialLib/MPL/Properties/SaturationDependentThermalConductivity.cpp
@@ -7,30 +7,30 @@
  *              http://www.opengeosys.org/project/license
  */
 
-#include "SaturationDependentHeatConduction.h"
+#include "SaturationDependentThermalConductivity.h"
 
 #include "MaterialLib/MPL/Medium.h"
 
 namespace MaterialPropertyLib
 {
-SaturationDependentHeatConduction::SaturationDependentHeatConduction(
+SaturationDependentThermalConductivity::SaturationDependentThermalConductivity(
     std::string name, double const K_dry, double const K_wet)
     : K_dry_(K_dry), K_wet_(K_wet)
 {
     name_ = std::move(name);
 }
 
-void SaturationDependentHeatConduction::checkScale() const
+void SaturationDependentThermalConductivity::checkScale() const
 {
     if (!std::holds_alternative<Medium*>(scale_))
     {
         OGS_FATAL(
-            "The property 'SaturationDependentHeatConduction' is "
+            "The property 'SaturationDependentThermalConductivity' is "
             "implemented on the 'medium' scale only.");
     }
 }
 
-PropertyDataType SaturationDependentHeatConduction::value(
+PropertyDataType SaturationDependentThermalConductivity::value(
     VariableArray const& variable_array,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
@@ -41,14 +41,14 @@ PropertyDataType SaturationDependentHeatConduction::value(
     return K_dry_ * (1 - S_L) + K_wet_ * S_L;
 }
 
-PropertyDataType SaturationDependentHeatConduction::dValue(
+PropertyDataType SaturationDependentThermalConductivity::dValue(
     VariableArray const& /*variable_array*/, Variable const variable,
     ParameterLib::SpatialPosition const& /*pos*/, double const /*t*/,
     double const /*dt*/) const
 {
     (void)variable;
     assert((variable == Variable::liquid_saturation) &&
-           "SaturationDependentHeatConduction::dvalue is implemented for "
+           "SaturationDependentThermalConductivity::dvalue is implemented for "
            "derivatives with respect to liquid saturation only.");
 
     return K_wet_ - K_dry_;
diff --git a/Tests/MaterialLib/TestSaturationDependentHeatConduction.cpp b/Tests/MaterialLib/TestSaturationDependentThermalConductivity.cpp
similarity index 82%
rename from Tests/MaterialLib/TestSaturationDependentHeatConduction.cpp
rename to Tests/MaterialLib/TestSaturationDependentThermalConductivity.cpp
index fd9bbd89472..deb87253cbe 100644
--- a/Tests/MaterialLib/TestSaturationDependentHeatConduction.cpp
+++ b/Tests/MaterialLib/TestSaturationDependentThermalConductivity.cpp
@@ -15,19 +15,19 @@
 #include <boost/math/constants/constants.hpp>
 
 #include "MaterialLib/MPL/Medium.h"
-#include "MaterialLib/MPL/Properties/CreateSaturationDependentHeatConduction.h"
-#include "MaterialLib/MPL/Properties/SaturationDependentHeatConduction.h"
+#include "MaterialLib/MPL/Properties/CreateSaturationDependentThermalConductivity.h"
+#include "MaterialLib/MPL/Properties/SaturationDependentThermalConductivity.h"
 #include "MaterialLib/MPL/Utils/FormEigenTensor.h"
 #include "ParameterLib/ConstantParameter.h"
 #include "TestMPL.h"
 #include "Tests/TestTools.h"
 
-TEST(MaterialPropertyLib, SaturationDependentHeatConduction)
+TEST(MaterialPropertyLib, SaturationDependentThermalConductivity)
 {
     double const k_dry = 0.2;
     double const k_wet = 1.5;
 
-    auto const k_model_eff = MPL::SaturationDependentHeatConduction(
+    auto const k_model_eff = MPL::SaturationDependentThermalConductivity(
         "thermal_conductivity", k_dry, k_wet);
 
     ParameterLib::SpatialPosition const pos;
diff --git a/MaterialLib/MPL/Properties/SaturationDependentHeatConduction.h b/MaterialLib/MPL/Properties/SaturationDependentThermalConductivity.h
similarity index 81%
rename from MaterialLib/MPL/Properties/SaturationDependentHeatConduction.h
rename to MaterialLib/MPL/Properties/SaturationDependentThermalConductivity.h
index 4a8788ac77c..0aa1174476b 100644
--- a/MaterialLib/MPL/Properties/SaturationDependentHeatConduction.h
+++ b/MaterialLib/MPL/Properties/SaturationDependentThermalConductivity.h
@@ -13,14 +13,14 @@
 namespace MaterialPropertyLib
 {
 /// Saturation dependent model for effective heat conduction
 /// \details This model is for the porous media with isotropic heat conductivity. This property must be a medium property, it
 /// computes the effetive heat conductivity based on a wet
 /// and a dry value
 /// \f$ K_{\mathrm{eff}} = S K_{\mathrm{wet}} + (1-S) K_{\mathrm{dry}} \f$
-class SaturationDependentHeatConduction final : public Property
+class SaturationDependentThermalConductivity final : public Property
 {
 public:
-    SaturationDependentHeatConduction(std::string name,
+    SaturationDependentThermalConductivity(std::string name,
                                       double const K_dry,
                                       double const K_wet);
 
@@ -13,14 +13,14 @@
 {
 /// Saturation dependent model for effective heat conduction
-/// \details This model is for the porous media with isotropic heat conductivity. This property must be a medium property, it
-/// computes the effetive heat conductivity based on a wet
+/// \details This model is for the porous media with isotropic thermal conductivity. This property must be a medium property, it
+/// computes the effective thermal conductivity based on a wet
 /// and a dry value
 /// \f$ K_{\mathrm{eff}} = S K_{\mathrm{wet}} + (1-S) K_{\mathrm{dry}} \f$
-- 
GitLab